@@ -485,10 +485,7 @@ mod tests {
 
     #[test]
     fn test_serialize_bool() {
-        assert!(match to_value(&true) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(to_value(&true), Err(Error::UnsupportedType)));
     }
 
     #[test]
@@ -573,19 +570,13 @@ mod tests {
     #[test]
     fn test_serialize_f32() {
         let value: f32 = 2.0;
-        assert!(match to_value(&value) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(to_value(&value), Err(Error::UnsupportedType)));
     }
 
     #[test]
     fn test_serialize_f64() {
         let value: f64 = 2.0;
-        assert!(match to_value(&value) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(to_value(&value), Err(Error::UnsupportedType)));
     }
 
     #[test]
@@ -624,19 +615,13 @@ mod tests {
     #[test]
     fn test_serialize_unit() {
         let value = ();
-        assert!(match to_value(&value) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(to_value(&value), Err(Error::UnsupportedType)));
     }
 
     #[test]
     fn test_serialize_none() {
         let value: Option<i64> = None;
-        assert!(match to_value(&value) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(to_value(&value), Err(Error::UnsupportedType)));
     }
 
     #[test]
@@ -649,46 +634,39 @@ mod tests {
     fn test_serialize_unit_struct() {
         use serde::Serializer;
 
-        assert!(match super::Serializer.serialize_unit_struct("Nothing") {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(
+            super::Serializer.serialize_unit_struct("Nothing"),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
     fn test_serialize_unit_variant() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_unit_variant("Nothing", 0, "Case") {
-                Err(Error::UnsupportedType) => true,
-                _ => false,
-            }
-        );
+        assert!(matches!(
+            super::Serializer.serialize_unit_variant("Nothing", 0, "Case"),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
     fn test_serialize_newtype_struct() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_newtype_struct("Nothing", &2) {
-                Err(_) => false,
-                Ok(_) => true,
-            }
-        );
+        assert!(super::Serializer
+            .serialize_newtype_struct("Nothing", &2)
+            .is_ok());
     }
 
     #[test]
     fn test_serialize_newtype_variant() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_unit_variant("Nothing", 0, "Case") {
-                Err(Error::UnsupportedType) => true,
-                _ => false,
-            }
-        );
+        assert!(matches!(
+            super::Serializer.serialize_unit_variant("Nothing", 0, "Case"),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
@@ -714,46 +692,40 @@ mod tests {
     fn test_serialize_tuple() {
         use serde::Serializer;
 
-        assert!(match super::Serializer.serialize_tuple(0) {
-            Err(Error::UnsupportedType) => true,
-            _ => false,
-        });
+        assert!(matches!(
+            super::Serializer.serialize_tuple(0),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
     fn test_serialize_tuple_struct() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_tuple_struct("Tuple Struct", 2) {
-                Err(Error::UnsupportedType) => true,
-                _ => false,
-            }
-        );
+        assert!(matches!(
+            super::Serializer.serialize_tuple_struct("Tuple Struct", 2),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
     fn test_serialize_tuple_variant() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_tuple_variant("Tuple Variant", 2, "Case", 1) {
-                Err(Error::UnsupportedType) => true,
-                _ => false,
-            }
-        );
+        assert!(matches!(
+            super::Serializer.serialize_tuple_variant("Tuple Variant", 2, "Case", 1),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
     fn test_serialize_struct_variant() {
         use serde::Serializer;
 
-        assert!(
-            match super::Serializer.serialize_struct_variant("Struct Variant", 2, "Case", 1) {
-                Err(Error::UnsupportedType) => true,
-                _ => false,
-            }
-        );
+        assert!(matches!(
+            super::Serializer.serialize_struct_variant("Struct Variant", 2, "Case", 1),
+            Err(Error::UnsupportedType)
+        ));
     }
 
     #[test]
